using System;
using System.Threading;

using Microsoft.SPOT;
using Microsoft.SPOT.Hardware;

using GHIElectronics.NETMF.FEZ;
using GHIElectronics.NETMF.Hardware;
using FEZTouch.UIControls;

namespace FEZTouchTest
{
    public class Program
    {
        public static FEZ_Components.FEZTouch ft;
        public static TextArea text_area;
        public static LED button_led;
        public static OutputCompare button_click_oc;
        public static Label h_lbl_val;
        public static Label v_lbl_val;
        public static Slider vertical_slider;
        public static Slider horiz_slider;
        public static ListBox list_box;
        public static StateButton on_off_btn;

        public static void Main()
        {
            FEZ_Components.FEZTouch.LCDConfiguration lcd_config = new FEZ_Components.FEZTouch.LCDConfiguration(
                FEZ_Pin.Digital.Di28,
                FEZ_Pin.Digital.Di20,
                FEZ_Pin.Digital.Di22,
                FEZ_Pin.Digital.Di23,
                new FEZ_Pin.Digital[8] { FEZ_Pin.Digital.Di51, FEZ_Pin.Digital.Di50, FEZ_Pin.Digital.Di49, FEZ_Pin.Digital.Di48, FEZ_Pin.Digital.Di47, FEZ_Pin.Digital.Di46, FEZ_Pin.Digital.Di45, FEZ_Pin.Digital.Di44 },
                FEZ_Pin.Digital.Di24,
                FEZ_Pin.Digital.Di26

                );

            FEZ_Components.FEZTouch.TouchConfiguration touch_config = new FEZ_Components.FEZTouch.TouchConfiguration(
                SPI.SPI_module.SPI2, FEZ_Pin.Digital.Di25, FEZ_Pin.Digital.Di34
                );

            ft = new FEZ_Components.FEZTouch(lcd_config, touch_config);
            ft.FillRectangle(0, 0, 240, 320, FEZ_Components.FEZTouch.Color.Black);  // Clear screen with black BG

            // Used for button clicks
            button_click_oc = new OutputCompare((Cpu.Pin)FEZ_Pin.Digital.Di5, false, 5);

            on_off_btn = new StateButton(0, 200, ft, 50, 30, "Off", "On");
            on_off_btn.StateChanged += new StateButton.State1ActiveDelegate(on_off_btn_StateChanged);

            button_led = new LED(15, 240, ft);

            text_area = new TextArea(80, 200, 160, 60, ft, FEZ_Components.FEZTouch.Color.Gray, FEZ_Components.FEZTouch.Color.White);

            vertical_slider = new Slider(200, 20, ft, 20, 140, Slider.eOrientation.Vertical);
            vertical_slider.ValueChanged += new Slider.ValueChangedDelegate(vertical_slider_ValueChanged);

            horiz_slider = new Slider(20, 155, ft, 150, 100, 200, Slider.eOrientation.Horizontal);
            horiz_slider.ValueChanged += new Slider.ValueChangedDelegate(horiz_slider_ValueChanged);

            Label h_lbl;
            h_lbl = new Label(0, 180, ft, 40, 10, "H-SldrVal:");
           
            h_lbl_val = new Label(80, 180, ft, 30, 10, "");
            h_lbl_val.Text = horiz_slider.Value.ToString();

            Label v_lbl;
            v_lbl = new Label(120, 180, ft, 40, 10, "V-SldrVal:");

            v_lbl_val = new Label(200, 180, ft, 30, 10, "");
            v_lbl_val.Text = vertical_slider.Value.ToString();

            // ScrollingGraph doesn't work yet.
            //ScrollingGraph sg = new ScrollingGraph(0, 245, 240, 60, ft);
            //sg.DataGrabberFunction = new ScrollingGraph.DataGrabberDelegate(GetVerticalSliderValue);
            //sg.MinValue = vertical_slider.MinValue;
            //sg.MaxValue = vertical_slider.MaxValue;

            String[] lbls = { "One", "Two", "Three", "Four", "Five" };
            RadioButton rb = new RadioButton(0, 0, ft, lbls, FEZ_Components.FEZTouch.Color.White, FEZ_Components.FEZTouch.Color.Gray, FEZ_Components.FEZTouch.Color.Green);
            rb.SelectedButtonChanged += new RadioButton.SelectedButtonChangedDelegate(rb_SelectedButtonChanged);
            rb.SelectedIndexChanged += new RadioButton.SelectedIndexChangedDelegate(rb_SelectedIndexChanged);

            CheckBox cb = new CheckBox(80, 0, ft, "SomeText", FEZ_Components.FEZTouch.Color.Green, FEZ_Components.FEZTouch.Color.Black, FEZ_Components.FEZTouch.Color.Yellow);
            CheckBox cb2 = new CheckBox(80, 21, ft, "More Text", FEZ_Components.FEZTouch.Color.Red, FEZ_Components.FEZTouch.Color.Black, FEZ_Components.FEZTouch.Color.Yellow);
            CheckBox cb3 = new CheckBox(80, 42, ft, "Select");
            CheckBox cb4 = new CheckBox(80, 63, ft, "Select 23");
            CheckBox cb5 = new CheckBox(80, 84, ft, "Select 45");

            CheckBox[] cba = new CheckBox[] { cb, cb2, cb3, cb4, cb5 };
            list_box = new ListBox(cba);

            MomentaryButton sel_all = new MomentaryButton(80, 115, ft, 90, 15, "Sel All");
            sel_all.Pressed += new MomentaryButton.ButtonPressedDelegate(sel_all_Pressed);

            MomentaryButton clr_all = new MomentaryButton(80, 135, ft, 90, 15, "Clr All");
            clr_all.Pressed += new MomentaryButton.ButtonPressedDelegate(clr_all_Pressed);

            MomentaryButton clr_txt = new MomentaryButton(180, 265, ft, 60, 15, "ClrTxt");
            clr_txt.Pressed += new MomentaryButton.ButtonPressedDelegate(clr_txt_Pressed);

            MomentaryButton check_lb_btn = new MomentaryButton(0, 280, ft, 50, 30, FEZ_Components.FEZTouch.Color.Yellow, FEZ_Components.FEZTouch.Color.Blue, "ChkLB");
            check_lb_btn.Pressed += new MomentaryButton.ButtonPressedDelegate(check_lb_btn_Pressed);

            MomentaryButton max_sliders_btn = new MomentaryButton(55, 280, ft, 50, 30, FEZ_Components.FEZTouch.Color.Yellow, FEZ_Components.FEZTouch.Color.Blue, "MaxSL");
            max_sliders_btn.Pressed += new MomentaryButton.ButtonPressedDelegate(max_sliders_btn_Pressed);

            MomentaryButton min_sliders_btn = new MomentaryButton(110, 280, ft, 50, 30, FEZ_Components.FEZTouch.Color.Yellow, FEZ_Components.FEZTouch.Color.Blue, "MinSL");
            min_sliders_btn.Pressed += new MomentaryButton.ButtonPressedDelegate(min_sliders_btn_Pressed);
            
            Thread.Sleep(Timeout.Infinite);
        }

        static void min_sliders_btn_Pressed()
        {
            horiz_slider.Value = horiz_slider.MinValue;
            vertical_slider.Value = vertical_slider.MinValue;
        }

        static void max_sliders_btn_Pressed()
        {
            horiz_slider.Value = horiz_slider.MaxValue;
            vertical_slider.Value = vertical_slider.MaxValue;
        }

        static void check_lb_btn_Pressed()
        {
            String s = "";
            int[] ia = list_box.SelectedIndices;
            foreach (int i in ia)
            {
                s += i.ToString() + " ";
            }
            text_area.WriteLine(s);
        }

        static int GetVerticalSliderValue()
        {
            return vertical_slider.Value;
        }

        static void on_off_btn_StateChanged(StateButton.eCurrState new_state)
        {
            button_led.Toggle();
        }

        static void horiz_slider_ValueChanged(int val)
        {
            h_lbl_val.Text = val.ToString();
        }

        static void rb_SelectedIndexChanged(int idx)
        {
            horiz_slider.Value = 125;
            vertical_slider.Value = 102;
        }

        static void clr_txt_Pressed()
        {
            text_area.Clear();
        }

        static void clr_all_Pressed()
        {
            list_box.ClearAll();
        }

        static void sel_all_Pressed()
        {
            list_box.SelectAll();
        }

        static void rb_SelectedButtonChanged(string lbl)
        {
            text_area.WriteLine("RB txt: " + lbl);
        }

        static void vertical_slider_ValueChanged(int val)
        {
            v_lbl_val.Text = val.ToString();
        }
    }
}
